pub struct FheKeys { /* private fields */ }Expand description
FHE client keys for encryption/decryption
When the fhe feature is enabled, this wraps TFHE client keys for real
homomorphic encryption. Without the feature, it acts as a passthrough stub.
Implementations
Sourceimpl FheKeys
impl FheKeys
Sourcepub fn generate() -> Result<Self>
pub fn generate() -> Result<Self>
Generate new FHE keys
This is a computationally expensive operation (can take several seconds)
when the fhe feature is enabled.
Sourcepub fn load_from_file(path: impl AsRef<Path>) -> Result<Self>
pub fn load_from_file(path: impl AsRef<Path>) -> Result<Self>
Load keys from a file
Reads serialized key data from the given path and deserializes
using oxicode (when fhe + serialization features are enabled).